## htbulma = "HTag bulma"

Example of gui toolkit using [htag](https://github.com/manatlan/htag).

<a href="https://pypi.org/project/htbulma/">
    <img src="https://badge.fury.io/py/htbulma.svg" alt="Package version">
</a>

**Just to be clear** : This module is just for me ;-). It's just here to demonstrate that you can build a py3 module, containnig a set of [htag](https://github.com/manatlan/htag)'s components, ready to be used, in you [htag](https://github.com/manatlan/htag) app.

Of course, you can use it, at your own risk. But be aware that :

 * the current components may change completly (and broke your apps)
 * many of them are not well coded (80% coming from the old gtag, and 70% are not using the last htag features in the right place)
 
Theses are my components, for my quick's htag apps ;-), for demo'ing the htag goal !

I'd love too see a real module, well maintained, with high-end and clever components (but I have no time to manage that, focusing on other projects (ex: htag))

[See an example](test.py)
